#!/bin/sh
a="/${0}"; a=${a%/*}; a=${a#/}; a=${a:-.}; BINDIR=`cd $a; pwd`

# Configurables
YUM="$BINDIR/yumrg/yumrg.sh -rd"
REPO="http://ooo.englab.brq.redhat.com/c/grid.git/plain"
REQS="qpid-cpp-client-devel gcc-c++ condor-qmf qpid-cpp-server qmf-devel"
COREPATTERN="core.*[0-9]"

##
alias yum="$YUM"
ulimit -c unlimited
CONDORCFG=~condor/condor_config.local

my_download_test () {
  test -r test_triggers.cpp && return 0
  echo Downloading test source...
  VERSION="`rpm -q condor --qf "%{version}-%{release}"`"
  VERSION="${VERSION%.*}"
  SRCPATH="$REPO/src/condor_triggerd/test_triggers.cpp?h=$VERSION"
  curl --silent "$SRCPATH" > test_triggers.cpp
}

my_condor_settle () {
  echo -n Waiting for Condor slots to show up
  while
    ! condor_status -any | grep -q Machine
  do
    echo -n "."
    sleep 1
  done
  echo -e ".\n"
}

my_compile_test () {
  test -x test_triggers && return 0
  echo Compiling test...
  g++ -g test_triggers.cpp -lqmfconsole -o test_triggers
}

my_condor_config () {
  grep -q triggerd_test.sh $CONDORCFG && return 0
  echo Configuring Condor...
	cat > $CONDORCFG <<-EOFCONCON
		# Configured for triggerd_test.sh
		CONDOR_DEVELOPERS = NONE
		CONDOR_HOST = \$(FULL_HOSTNAME)
		COLLECTOR_NAME = Personal Condor Testing Triggerd
		START = TRUE
		SUSPEND = FALSE
		PREEMPT = FALSE
		KILL = FALSE
		DAEMON_LIST = COLLECTOR, MASTER, NEGOTIATOR, SCHEDD, STARTD
		NEGOTIATOR_INTERVAL = 20
		LOCAL_CONFIG_DIR = \$(LOCAL_DIR)/config
		TRUST_UID_DOMAIN = TRUE
		# Triggerd-related options follow
		STARTD_CRON_NAME = TRIGGER_DATA
		STARTD_CRON_AUTOPUBLISH = If_Changed
		TRIGGER_DATA_JOBLIST = GetData
		TRIGGER_DATA_GETDATA_PREFIX = Triggerd
		TRIGGER_DATA_GETDATA_EXECUTABLE = \$(BIN)/get_trigger_data
		TRIGGER_DATA_GETDATA_PERIOD = 5m
		TRIGGER_DATA_GETDATA_RECONFIG = FALSE
		DAEMON_LIST = \$(DAEMON_LIST), TRIGGERD
		QMF_BROKER_HOST = localhost
	EOFCONCON
}

my_qpidd_restart () {
  pgrep qpidd >/dev/null && return 0
  echo Restarting qpidd...
  service qpidd restart
}

my_condor_restart () {
  condor_status -any | grep -q Machine && return 0
  echo Restarting Condor...
  service condor restart
}

my_installpkg () {
  unset pkgs
  for pkg in $REQS
  do rpm -q $pkg || pkgs="$pkgs $pkg"
  done
  test -n "$pkgs" && {
    echo Installing packages...
    yum -q -y --nogpgcheck install $pkgs
  }
}

my_analyze_core () {
  for i in $COREPATTERN
  do
    test -r $i.txt && continue
    echo Analyzing file $i with gdb...
    gdb -batch -x $BINDIR/gdb.cmd ./test_triggers $i > $i.txt \
      && echo Traceback $i.txt written, deleting file $i. \
      && rm -rf $i
  done
}
  

my_installpkg &&
my_download_test &&
my_compile_test &&
my_condor_config &&
my_qpidd_restart &&
my_condor_restart &&
my_condor_settle &&
echo

condor_trigger_config -i
./test_triggers

echo
my_analyze_core
